@@ -77,6 +77,11 @@ impl<K: Hash + Eq, V> TimedCache<K, V> {
     fn new_store(capacity: Option<usize>) -> HashMap<K, (Instant, V)> {
         capacity.map_or_else(HashMap::new, HashMap::with_capacity)
     }
+
+    /// Returns a reference to the cache's `store`
+    pub fn get_store(&self) -> &HashMap<K, (Instant, V)> {
+        &self.store
+    }
 }
 
 impl<K: Hash + Eq, V> Cached<K, V> for TimedCache<K, V> {
@@ -311,7 +316,7 @@ mod tests {
     #[test]
     fn timed_cache_refresh() {
         let mut c = TimedCache::with_lifespan_and_refresh(2, true);
-        assert_eq!(c.refresh(), true);
+        assert!(c.refresh());
         assert_eq!(c.cache_get(&1), None);
         let misses = c.cache_misses().unwrap();
         assert_eq!(1, misses);
